pub fn add_import(
project: &ProjectRoot,
file_path: &str,
import_statement: &str,
) -> Result<(String, ApplyEvidence)>Expand description
Add an import statement to a file at the correct position.
pub fn add_import(
project: &ProjectRoot,
file_path: &str,
import_statement: &str,
) -> Result<(String, ApplyEvidence)>Add an import statement to a file at the correct position.