Functions
- is_
noise_ callee - Resolve call graph config via the unified language registry. Only a subset of languages have call graph queries defined. Filter out common std/builtin method calls that add noise to the call graph. Covers Rust std, Python builtins, JS/TS builtins, Go builtins, and Java/Kotlin stdlib.