Pure data types for semantic search results.
Unconditional — available whether or not the semantic feature is enabled.
Structs
- Embedding
Index Info - Embedding
Runtime Info - Semantic
Match - Result of a semantic search query.
Pure data types for semantic search results.
Unconditional — available whether or not the semantic feature is enabled.