Module import_graph

Module import_graph 

Structs

BlastRadiusEntry
DeadCodeEntry
DeadCodeEntryV2
FileNode
GraphCache
ImportanceEntry
ImporterEntry

Functions

extract_imports_for_file
Extract raw import strings from a file. Public for use by the indexer.
extract_imports_from_source
Extract imports from already-loaded source content (avoids re-reading disk).
find_dead_code
find_dead_code_v2
get_blast_radius
get_importance
get_importers
is_import_supported
Use lang_registry as the single source of truth for supported extensions.
resolve_module_for_file
Resolve a raw import string to a relative path within the project. Public for use by the indexer.
supports_import_graph