Find all functions called by function_name (optionally restricted to a file).
Callee names are resolved to their definition files via the 6-stage cascade.
Find all functions that call function_name across the project.
Edges are resolved via the 6-stage confidence cascade when an import graph is available.