Single source of truth for supported language extensions.
All extension-to-language dispatch tables across the codebase should derive from this registry to prevent mismatches.
Structs
- ExtEntry
- Metadata for a supported file extension.
Functions
- all_
extensions - Return all supported extensions.
- for_
extension - Look up an extension entry by lowercase extension string.
- import_
extensions - Return all extensions that support import analysis.
- language_
id - Return the LSP language identifier for an extension.
- supports_
imports - Whether import graph analysis is supported for this extension.
- supports_
imports_ for_ path - Whether import graph analysis is supported for a file path.
- supports_
symbols - Whether tree-sitter symbol parsing is supported for this extension. All registered extensions support symbols.